import"./outputWidgets.91c9f730.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="53475db5-fabc-4283-8661-b45394a72650",e._sentryDebugIdIdentifier="sentry-dbid-53475db5-fabc-4283-8661-b45394a72650")}catch{}})();const d=e=>{try{return new URL(e),!0}catch{return!1}};export{d as i};
//# sourceMappingURL=url.bd840ee9.js.map
