import"./outputWidgets.91c9f730.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},d=new Error().stack;d&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[d]="bc24fd2d-9282-4ff8-a3d6-78ea198700d9",e._sentryDebugIdIdentifier="sentry-dbid-bc24fd2d-9282-4ff8-a3d6-78ea198700d9")}catch{}})();function n(e,d){return e.toLocaleString(void 0,{hour12:!1,timeZoneName:"short",day:"2-digit",month:"2-digit",year:"numeric",hour:"2-digit",minute:"2-digit",second:"2-digit",weekday:"long",...d})}export{n as g};
//# sourceMappingURL=datetime.e263366a.js.map
