import{f as u,eG as a,eR as d}from"./outputWidgets.91c9f730.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="62f22f7c-768e-43d7-9462-567b2b0ec830",e._sentryDebugIdIdentifier="sentry-dbid-62f22f7c-768e-43d7-9462-567b2b0ec830")}catch{}})();function i(e){for(var t=1;t<arguments.length;t++){var n=arguments[t]!=null?Object(arguments[t]):{},r=Object.keys(n);typeof Object.getOwnPropertySymbols=="function"&&(r=r.concat(Object.getOwnPropertySymbols(n).filter(function(o){return Object.getOwnPropertyDescriptor(n,o).enumerable}))),r.forEach(function(o){c(e,o,n[o])})}return e}function c(e,t,n){return t in e?Object.defineProperty(e,t,{value:n,enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e}var f=function(t,n){var r=i({},t,n.attrs);return u(a,i({},r,{icon:d}),null)};f.displayName="DownOutlined";f.inheritAttrs=!1;const s=f;export{s as D};
//# sourceMappingURL=DownOutlined.7911c167.js.map
