import{F as t}from"./Form.f24a1c0a.js";import{b2 as f,cn as n}from"./outputWidgets.91c9f730.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="9f9caf8e-40bd-4af1-909f-960c4f1d5315",e._sentryDebugIdIdentifier="sentry-dbid-9f9caf8e-40bd-4af1-909f-960c4f1d5315")}catch{}})();t.useInjectFormItemContext=f;t.ItemRest=n;t.install=function(e){return e.component(t.name,t),e.component(t.Item.name,t.Item),e.component(n.name,n),e};
//# sourceMappingURL=index.4bd92eaa.js.map
