import{v as t,b as s,ev as a}from"./outputWidgets.91c9f730.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="226ed853-bbbd-4092-a2ea-ab972fc331da",e._sentryDebugIdIdentifier="sentry-dbid-226ed853-bbbd-4092-a2ea-ab972fc331da")}catch{}})();const d={},o={class:"organization-settings"};function r(e,n){return s(),a("div",o,"Organization settings")}const f=t(d,[["render",r]]);export{f as default};
//# sourceMappingURL=OrganizationSettings.bdb0c5b7.js.map
