import{K as n,L as a}from"./repository.cb501b72.js";import{E as p}from"./repository.4b8f2a92.js";import{d as s,b as m,c,u as e}from"./outputWidgets.91c9f730.js";import{l as d}from"./index.16c6c151.js";import"./asyncComputed.5cff1726.js";import"./workspaces.e0f5ccda.js";import"./runnerData.08a2f6cc.js";import"./url.bd840ee9.js";import"./record.48aae23b.js";import"./pubsub.25829540.js";import"./scripts.8ea61e22.js";import"./envVars.bfc20846.js";import"./api.9186109d.js";import"./index.cf4c23b9.js";import"./icons.e854b740.js";import"./contracts.generated.cc987ccb.js";import"./index.5a63d36f.js";import"./ant-design.b392f32d.js";import"./index.49f61aa4.js";import"./Modal.41a7632f.js";import"./Text.2f03529d.js";import"./Base.79932679.js";import"./Typography.c7c5698a.js";import"./index.6a722ed0.js";import"./Link.dd2279d6.js";import"./Paragraph.18e7082b.js";import"./Title.69e80303.js";import"./index.946fdb2e.js";import"./index.f6bc8d33.js";import"./index.91782368.js";import"./CollapsePanel.4c443ee5.js";import"./Timeline.d06a0a15.js";import"./index.981556bf.js";import"./index.447513b5.js";import"./isNumeric.75337b1e.js";import"./ExpandOutlined.a22b2405.js";import"./Card.a8631760.js";import"./TabPane.7a826f8d.js";import"./hasIn.d8588324.js";import"./DownOutlined.7911c167.js";import"./index.4bd92eaa.js";import"./Form.f24a1c0a.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[o]="07af4910-7ac2-4cad-b296-4f8daa5e98e4",t._sentryDebugIdIdentifier="sentry-dbid-07af4910-7ac2-4cad-b296-4f8daa5e98e4")}catch{}})();class f{constructor(o=d){this.fetch=o}async fork(o){return(await this.fetch("/_editor/api/stage_runs/fork",{method:"POST",body:JSON.stringify({stage_run_id:o}),headers:{"Content-Type":"application/json"}})).json()}}const eo=s({__name:"WorkflowKanban",setup(t){const o=new p,r=new f,i=new a("kanban");return(u,y)=>(m(),c(n,{"kanban-repository":e(o),storage:e(i),"stage-run-repository":e(r)},null,8,["kanban-repository","storage","stage-run-repository"]))}});export{eo as default};
//# sourceMappingURL=WorkflowKanban.ca3e3663.js.map
