import{g as d}from"./api.c4c95097.js";import{P as m}from"./Passwordless.5176a366.js";import{a as p}from"./asyncComputed.5cff1726.js";import{W as u}from"./WidgetsFrame.0eaed93e.js";import{d as f,eA as l,eB as _,b as c,ev as y,e as g,u as s,c as b,w as h,ex as w,f as v,v as k}from"./outputWidgets.91c9f730.js";import"./runnerData.08a2f6cc.js";import"./url.bd840ee9.js";import"./index.16c6c151.js";import"./pubsub.25829540.js";import"./index.bf798f8b.js";import"./icons.e854b740.js";import"./CircularLoading.71cd396c.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="4c17ca90-9b94-40e7-a8fe-94ea651c3c18",e._sentryDebugIdIdentifier="sentry-dbid-4c17ca90-9b94-40e7-a8fe-94ea651c3c18")}catch{}})();const x={class:"login"},I=f({__name:"Login",setup(e){const t=l(),a=_(),{result:o}=p(d),i=()=>{const{redirect:r,...n}=a.query;if(r){t.push({path:r,query:n,params:a.params});return}t.push({name:"playerKanban",query:n})};return(r,n)=>(c(),y("div",null,[g("div",x,[s(o)?(c(),b(u,{key:0,"main-color":s(o).mainColor,theme:s(o).theme,"font-family":s(o).fontFamily,style:{width:"100vw"}},{default:h(()=>[v(m,{onDone:i})]),_:1},8,["main-color","theme","font-family"])):w("",!0)])]))}});const A=k(I,[["__scopeId","data-v-33714d9d"]]);export{A as default};
//# sourceMappingURL=Login.a1c365ea.js.map
