import{S as p}from"./Sidebar.7fd09091.js";import{_ as c}from"./Navbar.vue_vue_type_script_setup_true_lang.af38e0a8.js";import{M as d,N as l,O as u}from"./icons.e854b740.js";import{d as f,eB as b,H as g,a as _,b as y,c as v,w as e,f as r}from"./outputWidgets.91c9f730.js";import{a as w}from"./asyncComputed.5cff1726.js";import"./router.e4c5e9fd.js";import"./index.7bd5dae7.js";import{O as z}from"./organization.15272921.js";import{B as h}from"./BaseLayout.a82df01e.js";import"./index.946fdb2e.js";import"./logo.084e5d7c.js";import"./Text.2f03529d.js";import"./Base.79932679.js";import"./Typography.c7c5698a.js";import"./index.ceb65d67.js";import"./ArrowRightOutlined.08fa31dd.js";import"./Form.f24a1c0a.js";import"./hasIn.d8588324.js";import"./popupNotifcation.e7a2b93a.js";import"./index.cf4c23b9.js";import"./record.48aae23b.js";import"./pubsub.25829540.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[a]="79aaa900-55f8-4305-be38-d3a662753f8a",o._sentryDebugIdIdentifier="sentry-dbid-79aaa900-55f8-4305-be38-d3a662753f8a")}catch{}})();const Q=f({__name:"Organization",setup(o){const i=b().params.organizationId,{result:t}=w(()=>z.get(i)),n=g(()=>t.value?[{label:"My organizations",path:"/organizations"},{label:t.value.name,path:`/organizations/${t.value.id}`}]:void 0),s=[{name:"Organization",items:[{name:"Projects",icon:d,path:"projects"},{name:"Editors",icon:l,path:"editors"},{name:"Billing",icon:u,path:"billing"}]}];return(I,B)=>{const m=_("router-view");return y(),v(h,null,{navbar:e(()=>[r(c,{breadcrumb:n.value},null,8,["breadcrumb"])]),sidebar:e(()=>[r(p,{class:"sidebar",sections:s})]),content:e(()=>[r(m)]),_:1})}}});export{Q as default};
//# sourceMappingURL=Organization.5ffca076.js.map
