import{cy as n}from"./outputWidgets.91c9f730.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},f=new Error().stack;f&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[f]="677b140c-160c-42f6-b2bd-ffe4f1193062",e._sentryDebugIdIdentifier="sentry-dbid-677b140c-160c-42f6-b2bd-ffe4f1193062")}catch{}})();const t=(e,f,r)=>{n.error({message:e,description:f,onClick:r})};export{t as p};
//# sourceMappingURL=popupNotifcation.e7a2b93a.js.map
