import{C as r,E as t,K as i,a as c,M as b,c as l,P as y,R as f,S as g,b as u,T as k,U as p,e as w,l as D}from"./toggleHighContrast.7bbfbd35.js";import"./outputWidgets.91c9f730.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="802560d5-5de4-4bb6-a7d5-d409c0a2606c",e._sentryDebugIdIdentifier="sentry-dbid-802560d5-5de4-4bb6-a7d5-d409c0a2606c")}catch{}})();export{r as CancellationTokenSource,t as Emitter,i as KeyCode,c as KeyMod,b as MarkerSeverity,l as MarkerTag,y as Position,f as Range,g as Selection,u as SelectionDirection,k as Token,p as Uri,w as editor,D as languages};
//# sourceMappingURL=editor.main.31798cc0.js.map
