import{V as c}from"./outputWidgets.91c9f730.js";import{c as i,d}from"./index.25e1c122.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="826e881a-ead6-4d7f-8e21-83226913a51c",e._sentryDebugIdIdentifier="sentry-dbid-826e881a-ead6-4d7f-8e21-83226913a51c")}catch{}})();const{DatePicker:n,WeekPicker:r,MonthPicker:t,YearPicker:f,TimePicker:m,QuarterPicker:a,RangePicker:o}=i(d),g=c(n,{WeekPicker:r,MonthPicker:t,YearPicker:f,RangePicker:o,TimePicker:m,QuarterPicker:a,install:e=>(e.component(n.name,n),e.component(o.name,o),e.component(t.name,t),e.component(r.name,r),e.component(a.name,a),e)});export{g as D,t as M,a as Q,o as R,r as W};
//# sourceMappingURL=dayjs.6e22ace2.js.map
