import{D as u}from"./DeleteOutlined.f8ba9770.js";import{f as a,eG as o}from"./outputWidgets.91c9f730.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="d750fcab-76fe-4432-9e9b-62629345b6b8",e._sentryDebugIdIdentifier="sentry-dbid-d750fcab-76fe-4432-9e9b-62629345b6b8")}catch{}})();function l(e){for(var t=1;t<arguments.length;t++){var n=arguments[t]!=null?Object(arguments[t]):{},r=Object.keys(n);typeof Object.getOwnPropertySymbols=="function"&&(r=r.concat(Object.getOwnPropertySymbols(n).filter(function(f){return Object.getOwnPropertyDescriptor(n,f).enumerable}))),r.forEach(function(f){d(e,f,n[f])})}return e}function d(e,t,n){return t in e?Object.defineProperty(e,t,{value:n,enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e}var i=function(t,n){var r=l({},t,n.attrs);return a(o,l({},r,{icon:u}),null)};i.displayName="DeleteOutlined";i.inheritAttrs=!1;const s=i;export{s as D};
//# sourceMappingURL=DeleteOutlined.a12d007d.js.map
