import"./outputWidgets.91c9f730.js";(function(){try{var x=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(x._sentryDebugIds=x._sentryDebugIds||{},x._sentryDebugIds[e]="3ca935c3-dbc2-4324-b37f-3dda5c00a42b",x._sentryDebugIdIdentifier="sentry-dbid-3ca935c3-dbc2-4324-b37f-3dda5c00a42b")}catch{}})();const t=()=>"xxxxxxxx-xxxx-4xxx-yxxx-xxxxxxxxxxxx".replace(/[xy]/g,function(x){const e=Math.random()*16|0;return(x=="x"?e:e&3|8).toString(16)});export{t as u};
//# sourceMappingURL=uuid.4846aa16.js.map
