import{B as i}from"./Base.79932679.js";import{A as o}from"./Link.dd2279d6.js";import{A as a}from"./Paragraph.18e7082b.js";import{A as r}from"./Text.2f03529d.js";import{A as d}from"./Title.69e80303.js";import{T as e}from"./Typography.c7c5698a.js";(function(){try{var n=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(n._sentryDebugIds=n._sentryDebugIds||{},n._sentryDebugIds[t]="22e28a2e-fedb-40df-a843-16b8de8cd114",n._sentryDebugIdIdentifier="sentry-dbid-22e28a2e-fedb-40df-a843-16b8de8cd114")}catch{}})();e.Text=r;e.Title=d;e.Paragraph=a;e.Link=o;e.Base=i;e.install=function(n){return n.component(e.name,e),n.component(e.Text.displayName,r),n.component(e.Title.displayName,d),n.component(e.Paragraph.displayName,a),n.component(e.Link.displayName,o),n};
//# sourceMappingURL=index.6a722ed0.js.map
