import{V as s,f as p,Q as d}from"./outputWidgets.91c9f730.js";import{B as c,b as f}from"./Base.79932679.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="a509a592-ce39-4055-bfb0-3622eeaee3cc",e._sentryDebugIdIdentifier="sentry-dbid-a509a592-ce39-4055-bfb0-3622eeaee3cc")}catch{}})();const i=()=>d(f(),["component"]),r=(e,a)=>{let{slots:t,attrs:o}=a;const n=s(s(s({},e),{component:"div"}),o);return p(c,n,t)};r.displayName="ATypographyParagraph";r.inheritAttrs=!1;r.props=i();const g=r;export{g as A};
//# sourceMappingURL=Paragraph.18e7082b.js.map
