import{eP as t,eQ as r}from"./outputWidgets.91c9f730.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="1bf01ff0-5c57-4a52-a4ca-8c61849c2346",e._sentryDebugIdIdentifier="sentry-dbid-1bf01ff0-5c57-4a52-a4ca-8c61849c2346")}catch{}})();function o(e,n){return t(1,arguments),r(e,Date.now(),n)}export{o as f};
//# sourceMappingURL=index.f6bc8d33.js.map
