import{C as n,A as o}from"./CollapsePanel.4c443ee5.js";import{T as t,A as f}from"./Timeline.d06a0a15.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},d=new Error().stack;d&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[d]="bf923135-ed72-4b74-9c75-81f064f6bc7d",e._sentryDebugIdIdentifier="sentry-dbid-bf923135-ed72-4b74-9c75-81f064f6bc7d")}catch{}})();n.Panel=o;n.install=function(e){return e.component(n.name,n),e.component(o.name,o),e};t.Item=f;t.install=function(e){return e.component(t.name,t),e.component(f.name,f),e};
//# sourceMappingURL=index.91782368.js.map
