import{u as s}from"./index.16c6c151.js";import{d,b,ev as l,f as n,u as r}from"./outputWidgets.91c9f730.js";import{g as f}from"./api.c4c95097.js";import{K as u,L as c}from"./repository.cb501b72.js";import{_ as g}from"./Navbar.vue_vue_type_script_setup_true_lang.577f32ed.js";import{a as y}from"./asyncComputed.5cff1726.js";import{P as _}from"./repository.4b8f2a92.js";import"./pubsub.25829540.js";import"./runnerData.08a2f6cc.js";import"./url.bd840ee9.js";import"./workspaces.e0f5ccda.js";import"./record.48aae23b.js";import"./scripts.8ea61e22.js";import"./envVars.bfc20846.js";import"./api.9186109d.js";import"./index.cf4c23b9.js";import"./icons.e854b740.js";import"./contracts.generated.cc987ccb.js";import"./index.5a63d36f.js";import"./ant-design.b392f32d.js";import"./index.49f61aa4.js";import"./Modal.41a7632f.js";import"./Text.2f03529d.js";import"./Base.79932679.js";import"./Typography.c7c5698a.js";import"./index.6a722ed0.js";import"./Link.dd2279d6.js";import"./Paragraph.18e7082b.js";import"./Title.69e80303.js";import"./index.946fdb2e.js";import"./index.f6bc8d33.js";import"./index.91782368.js";import"./CollapsePanel.4c443ee5.js";import"./Timeline.d06a0a15.js";import"./index.981556bf.js";import"./index.447513b5.js";import"./isNumeric.75337b1e.js";import"./ExpandOutlined.a22b2405.js";import"./Card.a8631760.js";import"./TabPane.7a826f8d.js";import"./hasIn.d8588324.js";import"./DownOutlined.7911c167.js";import"./index.4bd92eaa.js";import"./Form.f24a1c0a.js";import"./index.ceb65d67.js";import"./ArrowRightOutlined.08fa31dd.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[t]="23602349-5ac6-4712-a00b-59d5ba008bdb",o._sentryDebugIdIdentifier="sentry-dbid-23602349-5ac6-4712-a00b-59d5ba008bdb")}catch{}})();const uo=d({__name:"Kanban",setup(o){const t=new _(s),i=new c("kanban"),{result:a}=y(f);return(k,w)=>{var m,e,p;return b(),l("div",null,[n(g,{"brand-name":((m=r(a))==null?void 0:m.brandName)||((e=r(a))==null?void 0:e.name),"logo-url":(p=r(a))==null?void 0:p.logoUrl},null,8,["brand-name","logo-url"]),n(u,{"kanban-repository":r(t),storage:r(i)},null,8,["kanban-repository","storage"])])}}});export{uo as default};
//# sourceMappingURL=Kanban.e0a2108e.js.map
